@@ -103,14 +103,6 @@ PlaylistCollection::PlaylistCollection(PlayerManager *player, QStackedWidget *pl
 
     m_actionHandler = new ActionHandler(this);
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 82, 0)
-    // KDirLister's auto error handling seems to crash JuK during startup in
-    // readConfig().  This auto handler was removed in KF5.82 so no longer
-    // needs disabled afterward.
-
-    m_dirLister.setAutoErrorHandlingEnabled(false, playlistStack);
-#endif
-
     readConfig();
 }
 
